set_xticks — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# set_xticks

EBSPlot.set_xticks(tick_positions: List[int] | None = None, tick_names: List[str] | None = None, color: str = 'black')

  A method to set the x ticks

  Parameters:

    - tick_positions (List[int], optional) – A list of tick positions, by default None

    - tick_names (List[str], optional) – A list of tick names, by default None

    - color (str, optional) – A color for the ticks, by default “black”